iptables-converter - pythonic view
==================================

module: iptables_conv
---------------------

.. automodule:: iptables_conv
    :members:

.. autoclass:: iptables_conv.iptables_converter.ConverterError
    :members:

.. autoclass:: iptables_conv.iptables_converter.Chains
    :members:

.. autoclass:: iptables_conv.iptables_converter.Tables
    :members:

module: tests
-------------

From 0.9.10 on all future tests will be run by pytest. Prior
tests are written to use the unittest module.

.. automodule:: tests.test_iptables_converter
    :members:

.. automodule:: tests.test_iptables_options
    :members:
